@@ -4,9 +4,17 @@ from django.utils.translation import ugettext_lazy as _
 from templatesadmin import TemplatesAdminException
 from templatesadmin.edithooks import TemplatesAdminHook
 
-from mercurial import hg, ui
+from mercurial import hg, ui, match
 import os
 
+
+TEMPLATESADMIN_HG_ROOT = getattr(
+    settings,
+    'TEMPLATESADMIN_HG_ROOT',
+    None
+)
+
+
 class HgCommitHook(TemplatesAdminHook):
     '''
     Commit to git after saving
@@ -14,7 +22,8 @@ class HgCommitHook(TemplatesAdminHook):
 
     @classmethod
     def post_save(cls, request, form, template_path):
-        dir, file = os.path.dirname(template_path) + "/", os.path.basename(template_path)
+        dir = os.path.dirname(template_path) + os.sep
+        file = os.path.basename(template_path)
 
         if request.user.first_name and request.user.last_name:
             author = "%s %s" % (request.user.first_name, request.user.last_name)
@@ -23,24 +32,23 @@ class HgCommitHook(TemplatesAdminHook):
 
         message = form.cleaned_data['commitmessage'] or '--'
 
-        path = None
-        for template_dir in settings.TEMPLATE_DIRS:
-            if dir.startswith(template_dir):
-                if path is None or len(templare_dir)>len(path):
-                    path = template_dir
+        path = TEMPLATESADMIN_HG_ROOT
+        if path is None:
+            for template_dir in settings.TEMPLATE_DIRS:
+                if dir.startswith(template_dir):
+                    if path is None or len(templare_dir)>len(path):
+                        path = template_dir
         if path is None:
             raise TemplatesAdminException("Could not find template base directory")
-        commit_file = template_path
-        if commit_file.startswith(path):
-            commit_file = commit_file[len(path):]
-            if commit_file.startswith("/"):
-                commit_file = commit_file[1:]
-        uio = ui.ui(interactive=False, report_untrusted=False, quiet=True)
+        uio = ui.ui()
+        uio.setconfig('ui', 'interactive', False)
+        uio.setconfig('ui', 'report_untrusted', False)
+        uio.setconfig('ui', 'quiet', True)
         repo = hg.repository(uio, path=path)
+        filter = match.match(repo.root, dir, [file])
+        repo.commit(match=filter, text=message, user="%s <%s>" % (author, request.user.email))
 
-        repo.commit([str(commit_file)], text=message, user="%s <%s>" % (author, request.user.email))
-
-        return "Template '%s' was committed succesfully into mercurial repository." % commit_file
+        return "Template '%s' was committed succesfully into mercurial repository." % file
 
     @classmethod
     def contribute_to_form(cls, template_path):
